@@ -4,16 +4,14 @@ Main interface for workmailmessageflow service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_workmailmessageflow import (
         Client,
         WorkMailMessageFlowClient,
     )
 
-    session = boto3.Session()
-
-    client: WorkMailMessageFlowClient = boto3.client("workmailmessageflow")
-    session_client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
+    session = Session()
+    client: WorkMailMessageFlowClient = session.client("workmailmessageflow")
     ```
 """
 from .client import WorkMailMessageFlowClient
