@@ -86,7 +86,7 @@ class WorkMailMessageFlowClient(BaseClient):
         """
 
     def put_raw_message_content(
-        self, *, messageId: str, content: "RawMessageContentTypeDef"
+        self, *, messageId: str, content: RawMessageContentTypeDef
     ) -> Dict[str, Any]:
         """
         Updates the raw content of an in-transit email message, in MIME format.
